@@ -157,7 +157,7 @@ class EventNotifyHandler(EventNotifyHandlerBase):
 
     # pylint: disable=no-self-use, missing-docstring
     def log_event(self, seq, service_id, timestamp):
-        log.info("Event %s received for %s service at %s", seq, service_id, timestamp)
+        log.debug("Event %s received for %s service at %s", seq, service_id, timestamp)
 
 
 class EventListener(EventListenerBase):
@@ -191,8 +191,6 @@ class EventListener(EventListenerBase):
                 address reachable by the Sonos net.
 
         """
-        if not self.session:
-            self.session = ClientSession()
         if not self.start_lock:
             self.start_lock = asyncio.Lock()
         async with self.start_lock:
@@ -209,6 +207,7 @@ class EventListener(EventListenerBase):
             if not port:
                 return
             self.address = (ip_address, port)
+            self.session = ClientSession()
             self.is_running = True
             log.debug("Event Listener started")
 
@@ -240,7 +239,7 @@ class EventListener(EventListenerBase):
         ):
             try:
                 if port_number > self.requested_port_number:
-                    log.warning("Trying next port (%d)", port_number)
+                    log.debug("Trying next port (%d)", port_number)
                 # pylint: disable=no-member
                 sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
                 sock.bind((ip_address, port_number))
@@ -250,7 +249,7 @@ class EventListener(EventListenerBase):
                 break
             # pylint: disable=invalid-name
             except socket.error as e:
-                log.warning(e)
+                log.debug(e)
                 continue
 
         if not self.port:
@@ -269,7 +268,7 @@ class EventListener(EventListenerBase):
         await self.runner.setup()
         self.site = web.SockSite(self.runner, self.sock)
         await self.site.start()
-        log.info("Event listener running on %s", (self.ip_address, self.port))
+        log.debug("Event listener running on %s", (self.ip_address, self.port))
 
     async def async_stop(self):
         """Stop the listener."""
